#!/bin/bash

# Make sure 'ifup-routes' and 'ifup' have our handler provisions:
/usr/sausalito/constructor/base/network/10_fix_ifup.pl

# Make sure our IPs are all bound and our routes are all OK:
#/usr/sausalito/handlers/base/network/change_route.pl -c 2 >/dev/null 2>&1 || :

# Fix PHP Session dir GID if needed:
if [ -d "/var/lib/php/session" ];then
    SESSPERMS=`ls -la /var/lib/php|grep session|awk '{print $1}'`
    if [ $SESSPERMS != "drwxrwxrwx" ];then
        chmod 777 /var/lib/php/session
    fi
fi

# Remove the OS supplied YUM autoupdater (if present), as we bring our own:
if [ -f /etc/cron.daily/yum-autoupdate ] ; then
    rm -f /etc/cron.daily/yum-autoupdate
fi

# The CD-Installer of BlueOnyx brings /usr/bin/fix-httpd-log-dir aboard, but
# it might not be executable:
if [ -f /usr/bin/fix-httpd-log-dir ]; then
    chmod 755 /usr/bin/fix-httpd-log-dir
fi

# While we are at it, delete the default CentOS welcome page:
if [ -f /etc/httpd/conf.d/welcome.conf ]; then
        /bin/rm -f /etc/httpd/conf.d/welcome.conf
fi

# Also delete /etc/httpd/conf.d/manual.conf:
if [ -f /etc/httpd/conf.d/manual.conf ]; then
        /bin/rm -f /etc/httpd/conf.d/manual.conf
fi

# Also remove server.conf
if [ -f /etc/httpd/conf.d/server.conf ]; then
        /bin/rm -f /etc/httpd/conf.d/server.conf
fi

# Also remove /etc/httpd/conf.d/userdir.conf
if [ -f /etc/httpd/conf.d/userdir.conf ]; then
        /bin/rm -f /etc/httpd/conf.d/userdir.conf
fi

# ProFTPd 1.3.7 fixes:
FTP=`/bin/cat /etc/proftpd.conf | /bin/grep IdentLookups | /usr/bin/wc -l`
if [ "$FTP" -gt "0" ]; then
    if [ -f /etc/proftpd.conf.dist ];then
        cp /etc/proftpd.conf.dist /etc/proftpd.conf
        service xinetd restart >/dev/null 2>&1 || :
    fi
fi
FTPS=`/bin/cat /etc/proftpds.conf | /bin/grep IdentLookups | /usr/bin/wc -l`
if [ "$FTPS" -gt "0" ]; then
    if [ -f /etc/proftpds.conf.dist ];then
        cp /etc/proftpds.conf.dist /etc/proftpds.conf
        service xinetd restart >/dev/null 2>&1 || :
    fi
fi

# Fix nss.conf if present:
if [ -f /etc/httpd/conf.d/nss.conf ]; then
NUMNSS=`/bin/cat /etc/httpd/conf.d/nss.conf | /bin/grep NSSEnforceValidCerts | /usr/bin/wc -l`
    if [ $NUMNSS = "0" ]; then
        sed -i "s/^NSSSession3CacheTimeout 86400/NSSSession3CacheTimeout 86400\\nNSSEnforceValidCerts off/g" /etc/httpd/conf.d/nss.conf
    fi
fi

# Need to turn off Chronyd, as we use NTPd:
if [ -f /usr/lib/systemd/system/chronyd.service ];then
    CHRONY=`LC_ALL=C systemctl status chronyd|grep "Active: active (running)"|wc -l`
    if [ $CHRONY -eq "1" ]; then
        systemctl stop chronyd &>/dev/null || :
        systemctl disable chronyd &>/dev/null || :
    fi
fi

# Fix DBUS issue if /var/run/dbus/system_bus_socket no longer is a Symlink:
#if [ -f /usr/bin/systemctl ];then
#    if [ ! -L /var/run/dbus/system_bus_socket ];then
#        systemctl stop dbus
#        rm /var/run/dbus/system_bus_socket
#        ln -s /run/dbus/system_bus_socket /var/run/dbus/system_bus_socket
#        systemctl start dbus
#    fi
#fi

# Fix Imagetragick issue:
if [ -f /etc/ImageMagick/policy.xml ];then
    ITRAGIC=`cat /etc/ImageMagick/policy.xml |grep TEXT|wc -l`
    # We need to apply the fix:
    if [ $ITRAGIC -eq 0 ]; then
        # Do we have a good copy? We should!
        if [ -f /etc/ImageMagick/policy.xml.fixed ];then
            cp /etc/ImageMagick/policy.xml.fixed /etc/ImageMagick/policy.xml
        fi
    fi
fi

# CentOS 7 Snafu-fix:
if [ -f /usr/lib/systemd/system/auditd.service ];then
    AUDITD=`ls -la /usr/lib/systemd/system/auditd.service|grep "^-rw-r-----"|wc -l`
    if [ $AUDITD -eq 1 ]; then
        chmod 644 /usr/lib/systemd/system/auditd.service
    fi
fi

# Create Dovecot SSL parameters (DH-stuff) if it's missing:
if [ ! -f /var/lib/dovecot/ssl-parameters.dat ];then
    if [ -f /var/lib/dovecot/ssl-parameters.dat.precalc ];then
      cp /var/lib/dovecot/ssl-parameters.dat.precalc /var/lib/dovecot/ssl-parameters.dat
      chmod 0644 /var/lib/dovecot/ssl-parameters.dat
    else
        /usr/libexec/dovecot/ssl-params &>/dev/null
    fi
fi

# Epel:
# 
# People don't learn. If Epel is present, we disable it. Am sick of fixing broken boxes:
#
if [ -f /etc/yum.repos.d/epel.repo ];then
    sed -i -e 's|enabled=1|enabled=0|' /etc/yum.repos.d/epel.repo
fi

# Mitigation for CVE-2021-4034 until a fixed 'polkit' RPM is released upstream:
POLKIT=`rpm -q --changelog polkit|grep CVE-2021-4034|wc -l`
if [ $POLKIT -eq 0 ] && [ -f /usr/bin/pkexec ]; then
     POLCHECK=`ls -la /usr/bin/pkexec|grep '^-rwsr-xr-x'|wc -l`
     if [ $POLCHECK -eq 1 ]; then
          chmod 0755 /usr/bin/pkexec
     fi
fi

#
### Fixing "GLIBC Vulnerability on Servers Serving PHP" (CVE-2024-2961) via Hotfix:
#

# Check for the presence of ISO-2022-CN-EXT in the list of encodings
encoding_count=$(iconv -l | grep -E 'CN-?EXT' | wc -l)

if [ "$encoding_count" -gt 0 ]; then
    echo "Fixing CVE-2024-2961 'GLIBC Vulnerability on Servers Serving PHP'"

    # Specify the file path
    file_path="/usr/lib64/gconv/gconv-modules"

    # Check if the file exists
    if [ -f "$file_path" ]; then

        # Using sed to delete lines containing 'ISO-2022-CN-EXT'
        sed -i '/ISO-2022-CN-EXT/d' "$file_path"

        # Save the current directory
        original_dir=$(pwd)

        # Change to the directory where gconv-modules are located
        cd /usr/lib64/gconv
        
        # Run iconvconfig:
        /usr/sbin/iconvconfig

        # Change back to the original directory
        cd "$original_dir"
    fi
fi

#
### ScriptAlias /cgi-bin/ fix in httpd.conf:
#

# Define the path to the configuration file
config_file="/etc/httpd/conf/httpd.conf"

# Define the line to search for
search_line="    ScriptAlias /cgi-bin/ \"/var/www/cgi-bin/\""

# Check if the line exists and is not already commented out
if grep -q "^${search_line}" "$config_file"; then
    sed -i "s|^${search_line}|#&|" "$config_file"
fi

#
### Last rites before exit:
#

# Check if restart or rehash files exists and are older than 38 minutes
restart_file="/usr/sausalito/yumcce/restart"
rehash_file="/usr/sausalito/yumcce/rehash"
if [ -f "$restart_file" ] && [ $(find "$restart_file" -mmin +38) ]; then
    echo "Restart file exists and is older than 38 minutes"
    # Restart CCEd:
    /usr/sausalito/sbin/cced.init restart
    rm -f /usr/sausalito/yumcce/restart
    rm -f /usr/sausalito/yumcce/rehash
elif [ -f "$rehash_file" ] && [ $(find "$rehash_file" -mmin +38) ]; then
    echo "Rehash file exists and is older than 38 minutes"
    # Rehash CCEd:
    /usr/sausalito/sbin/cced.init rehash
    rm -f /usr/sausalito/yumcce/rehash
fi

# End:
exit

#
# Copyright (c) 2008-2024 Michael Stauber, SOLARSPEED.NET
# Copyright (c) 2008-2024 Team BlueOnyx, BLUEONYX.IT
# All Rights Reserved.
#
# 1. Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in
#   the documentation and/or other materials provided with the
#   distribution.
#
# 3. Neither the name of the copyright holder nor the names of its
#   contributors may be used to endorse or promote products derived
#   from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# You acknowledge that this software is not designed or intended for
# use in the design, construction, operation or maintenance of any
# nuclear facility.
#
